{% load i18n %}

{% if perms.afat.manage_afat and is_clickable_link and manual_fat_can_be_added %}
    <div id="manualfat" class="tab-pane fade in panel panel-default">
        <div class="panel-body">
            <h4>{% translate "Manual FAT" %}</h4>

            <p>
                {% translate "Is someone missing from the list of FATs? Use this form to add them." %}
                <br>
                <strong>{% translate "Note:" %}</strong> {% translate "This action is logged!" %}
            </p>

            <form class="form" role="form" action="" method="POST">
                {% csrf_token %}
                <div class="form-group">
                    <div class="row">
                        <div class="col-md-12">
                            <label class="control-label" for="character">
                                <span class="form-field-required">
                                    {% translate "Character Name" %}
                                    <span aria-label="{% translate 'This field is mandatory' %}" class="form-required-marker">*</span>
                                </span>
                            </label>

                            <input type="text" class="form-control" name="character" id="character" placeholder='{% translate "Character Name" %}' required>
                        </div>
                    </div>
                </div>

                <div class="form-group">
                    <div class="row">
                        <div class="col-md-6">
                            <label class="control-label" for="system">
                                <span class="form-field-required">
                                    {% translate "System" %}
                                    <span aria-label="{% translate 'This field is mandatory' %}" class="form-required-marker">*</span>
                                </span>
                            </label>

                            <input type="text" class="form-control" name="system" id="system" placeholder='{% translate "System" %}' required>
                        </div>

                        <div class="col-md-6">
                            <label class="control-label" for="shiptype">
                                <span class="form-field-required">
                                    {% translate "Ship Type" %}
                                    <span aria-label="{% translate 'This field is mandatory' %}" class="form-required-marker">*</span>
                                </span>
                            </label>

                            <input type="text" class="form-control" name="shiptype" id="shiptype" placeholder='{% translate "Ship Type" %}' required>
                        </div>
                    </div>
                </div>

                <div class="form-group text-right">
                    <button class="btn btn-primary" type="submit" name="manual_fat">{% translate "Add Manual FAT" %}</button>
                </div>
            </form>
        </div>
    </div>
{% endif %}
