{% extends "afat/base.html" %}

{% load i18n %}

{% block page_title %}{% translate "Fleet Activity" %}{% endblock %}

{% block afat_header %}
    <br>
    {% include "afat/partials/menu.html" %}

    <h2>{% translate "Create a FAT Link" %}</h2>
{% endblock %}

{% block afat_body %}
    <div class="row">
        {% include "afat/partials/fatlinks/add/esi_link.html" %}
        {% include "afat/partials/fatlinks/add/clickable_link.html" %}
    </div>
{% endblock %}

{% block extra_css %}
    {% include "afat/bundles/afat-css.html" %}
{% endblock %}

{% block extra_javascript %}
    {% include "afat/bundles/afat-js.html" %}

    <script>
        $(document).ready(function () {
            let cancelEsiFleetModal = $('#cancelEsiFleetModal');

            manageModal(cancelEsiFleetModal);
        });
    </script>
{% endblock %}
