{% load i18n %}

<div class="tab-pane fade in panel panel-default" id="members">
    <div class="panel-body">
        <h3>{{ corporation }} {% translate "Members" %}</h3>

        <table class="table table-striped table-hover" id="corp-members" style="width: 100%;">
            <thead>
                <tr>
                    <th>{% translate "Character" %}</th>
                    <th>{% translate "FATs" %}</th>
                    <th><!-- {% translate "Character Stats" %} --></th>
                </tr>
            </thead>

            <tbody>
                {% for key, value in chars.items %}
                    <tr>
                        <td>{{ key }}</td>
                        <td>{{ value.0 }}</td>
                        <td class="text-right">
                            <a class="btn btn-primary btn-sm" href="{% url 'afat:statistics_character' value.1 year month %}">
                                <span class="glyphicon glyphicon-eye-open"></span>
                            </a>
                        </td>
                    </tr>
                {% endfor %}
            </tbody>
        </table>
    </div>
</div>
