# Generated by Django 3.1.5 on 2021-01-11 14:28

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("afat", "0015_afatlink_character"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="aaafat",
            options={
                "default_permissions": (),
                "managed": False,
                "permissions": (
                    ("basic_access", "Can access the AFAT module"),
                    ("manage_afat", "Can manage the AFAT module"),
                    ("add_fatlink", "Can create FAT Links"),
                    ("stats_corporation_own", "Can see own corporation statistics"),
                    (
                        "stats_corporation_other",
                        "Can see statistics of other corporations",
                    ),
                ),
                "verbose_name": "Alliance Auth AFAT",
            },
        ),
        migrations.AlterModelOptions(
            name="afat",
            options={
                "default_permissions": (),
                "verbose_name": "FAT",
                "verbose_name_plural": "FATs",
            },
        ),
        migrations.AlterModelOptions(
            name="afatdellog",
            options={
                "default_permissions": (),
                "verbose_name": "Delete Log",
                "verbose_name_plural": "Delete Logs",
            },
        ),
        migrations.AlterModelOptions(
            name="afatlink",
            options={
                "default_permissions": (),
                "ordering": ("-afattime",),
                "verbose_name": "FAT Link",
                "verbose_name_plural": "FAT Links",
            },
        ),
        migrations.AlterModelOptions(
            name="afatlinktype",
            options={
                "default_permissions": (),
                "verbose_name": "FAT Link Fleet Type",
                "verbose_name_plural": "FAT Link Fleet Types",
            },
        ),
        migrations.AlterModelOptions(
            name="clickafatduration",
            options={
                "default_permissions": (),
                "verbose_name": "FAT Duration",
                "verbose_name_plural": "FAT Durations",
            },
        ),
        migrations.AlterModelOptions(
            name="manualafat",
            options={
                "default_permissions": (),
                "verbose_name": "Manual FAT Log",
                "verbose_name_plural": "Manual FAT Logs",
            },
        ),
    ]
