# Generated by Django 2.2.14 on 2020-08-16 20:42

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("afat", "0004_clickfatduration"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="afatlink",
            options={
                "ordering": ("-afattime",),
                "permissions": (
                    (
                        "manage_afat",
                        "Can manage the Another Fleet Activity Tracking module",
                    ),
                    ("stats_corp_own", "Can see own corp stats"),
                    ("stats_corp_other", "Can see stats of other corps."),
                    (
                        "stats_char_other",
                        "Can see stats of characters not associated with current user.",
                    ),
                ),
            },
        ),
        migrations.AddField(
            model_name="afat",
            name="deleted_at",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="afatlink",
            name="deleted_at",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
